package com.zyc.system.mapper;

import java.util.List;
import com.zyc.system.domain.SecurityServices;

/**
 * 安全服务Mapper接口
 * 
 * @author zyc
 * @date 2024-12-26
 */
public interface SecurityServicesMapper 
{
    /**
     * 查询安全服务
     * 
     * @param id 安全服务主键
     * @return 安全服务
     */
    public SecurityServices selectSecurityServicesById(Integer id);

    /**
     * 查询安全服务列表
     * 
     * @param securityServices 安全服务
     * @return 安全服务集合
     */
    public List<SecurityServices> selectSecurityServicesList(SecurityServices securityServices);

    /**
     * 新增安全服务
     * 
     * @param securityServices 安全服务
     * @return 结果
     */
    public int insertSecurityServices(SecurityServices securityServices);

    /**
     * 修改安全服务
     * 
     * @param securityServices 安全服务
     * @return 结果
     */
    public int updateSecurityServices(SecurityServices securityServices);

    /**
     * 删除安全服务
     * 
     * @param id 安全服务主键
     * @return 结果
     */
    public int deleteSecurityServicesById(Integer id);

    /**
     * 批量删除安全服务
     * 
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteSecurityServicesByIds(Integer[] ids);
}
